/**
 *  Class Hra - třída představující logiku adventury.
 * 
 *  Toto je hlavní třída  logiky aplikace.  Tato třída inicializuje ostatní třídy:
 *  vytváří všechny místnosti (třída Mistnost), vytváří seznam platných příkazů.
 *  Též vyhodnocuje jednotlivé příkazy zadané uživatelem.
 *
 *@author     Michael Kolling, Lubos Pavlicek, Jarmila Pavlickova
 *@version    3.0
 *@created    květen 2005
 */

class Hra {
    private SeznamPrikazu platnePrikazy;    // obsahuje seznam přípustných slov
    private Mistnost aktualniMistnost;
    private boolean konecHry = false;

    /**
     *  Vytváří hru a inicializuje místnosti a seznam platných příkazů.
     */
    public Hra() {
        zalozMistnosti();
        platnePrikazy = new SeznamPrikazu();
    }


    /**
     *  Vytváří jednotlivé místnosti a propojuje je pomocí východů.
     */
    private void zalozMistnosti() {
        Mistnost hala;
        Mistnost ucebna;
        Mistnost bufet;
        Mistnost chodba;
        Mistnost kancelar;

        // vytvářejí se jednotlivé místnosti
        hala = new Mistnost("hala","vstupni hala budovy VSE na Jiznim meste");
        ucebna = new Mistnost("ucebna", "prednaskova ucebna 103JM");
        bufet = new Mistnost("bufet","bufet, kam si muzete zajit na svacinku");
        chodba = new Mistnost("chodba","spojovaci chodba");
        kancelar = new Mistnost("kancelar","kancelar vaseho vyucujiciho Javy");

        // přiřazují se východy z místností (sousedící místnosti)
        hala.setVychod(ucebna);
        hala.setVychod(chodba);
        hala.setVychod(bufet);
        ucebna.setVychod(hala);
        bufet.setVychod(hala);
        chodba.setVychod(hala);
        chodba.setVychod(kancelar);
        kancelar.setVychod(chodba);

        aktualniMistnost = hala;  // hra začíná v místnosti hala
    }

    /**
     *  Vrátí úvodní zprávu pro hráče.
     */
    public String vratUvitani() {
        return "Vitejte!\n" +
               "Toto je nova, neuveritelne nudna adventura.\n" +
               "Napiste 'napoveda', pokud si nevite rady, jak hrat dal.\n" +
               "\n" +
               aktualniMistnost.dlouhyPopis();
    }
    
    /**
     *  Vrátí závěrečnou zprávu pro hráče.
     */
    public String vratEpilog() {
        return "Dik, ze jste si zahrali.  Ahoj.";
    }
    
    /** 
     * Vrací true, pokud hra skončila.
     */
     public boolean konecHry() {
        return konecHry;
    }

    /**
     *  Metoda zpracuje příkaz uvedený jako parametr, tj. spustí odpovídající
     *  metodu. Metoda vrací řetězec, který se má vypsat na obrazovku.
     *
     *@param  prikaz  příkaz, který se má zpracovat (provést)
     *@return          vrací se řetězec, který se má vypsat na obrazovku
     */
     public String zpracujPrikaz(Prikaz prikaz) {
        String textKVypsani=" .... ";
        if (platnePrikazy.jePlatnyPrikaz(prikaz.getSlovoPrikazu())) {
            String povel = prikaz.getSlovoPrikazu();
            if (povel.equals("napoveda")) {
                textKVypsani = napoveda();
            }
            else if (povel.equals("jdi")) {
                textKVypsani = jdi(prikaz);          
            }
            else if (povel.equals("konec")) {
                textKVypsani = konec(prikaz);
            }
        }
        else {
            textKVypsani="Nevim co tim myslis, tento prikaz neznam? ";
        }
        return textKVypsani;
    }

     // následuje implementace jednotlivých příkazů
     
    /**
     * V případě, že příkaz má jen jedno slovo "konec" hra končí, jinak pokračuje např. při zadání "konec a".
     * 
     * @ return Vrací true v případě, že příkaz má jen jedno slovo "konec", jinak vrací false
     */
    
    private String konec(Prikaz prikaz) {
        if (prikaz.maDruheSlovo()) {
            return "Ukoncit co? Nechapu, proc jste zadal druhe slovo.";
        }
        else {
            konecHry = true;
            return "hra ukončena příkazem konec";
        }
    }
    
    /**
     *  Vypíše základní nápovědu po zadání příkazu "napoveda". Nyní se vypisuje
     *  vcelku primitivní zpráva a seznam dostupných příkazů.
     */
    private String napoveda() {
        return "Ztratil ses. Jsi sam(a). Toulas se\n"
             + "po arealu skoly na Jiznim meste.\n"
             + "\n"
             + "Muzes zadat tyto prikazy:\n"
             + platnePrikazy.vratSeznamPrikazu();
    }

    /**
     *  Příkaz "jdi". Zkouší se vyjít zadaným směrem/do zadané místnosti. Pokud místnost
     *  existuje, vstoupí se do nové místnosti. Pokud zadaná sousední
     *  místnosti (východ) není, vypíše se chybové hlášení.
     *
     *@param  prikaz  příkaz - jako druhý parametr obsahuje jméno místnosti,
     *                         do které se má jít.
     */
    private String jdi(Prikaz prikaz) {
        if (!prikaz.maDruheSlovo()) {
            // pokud chybí druhé slovo (sousední místnost), tak ....
            return "Kam mám jít? Musíš zadat jméno místnosti";
        }

        String smer = prikaz.getDruheSlovo();

        // zkoušíme přejít do sousední místnosti
        Mistnost sousedniMistnost = aktualniMistnost.sousedniMistnost(smer);

        if (sousedniMistnost == null) {
            return "Tam se odsud jit neda!";
        }
        else {
            aktualniMistnost = sousedniMistnost;
            return aktualniMistnost.dlouhyPopis();
        }
    }
}

