/**
 * Class Prikaz - část jednoduché textové adventury.
 *
 * Třída udržuje informace o zadaném příkazu. V současné době může příkaz
 * mít až dvě slova (např. "jdi kuchyn").
 * Pokud má příkaz pouze jedno slovo, je jako druhé slovo uložena hodnota null.
 *
 * Třídu je možné rozšířit na příkazy se třemi či více slovy.
 *
 *@author     Michael Kolling, Lubos Pavlicek, Jarmila Pavlickova
 *@version    3.0
 *@created    květen 2005
 */

class Prikaz {
    private String slovoPrikazu = null;
    private String druheSlovo = null;

    /**
     * Vytváří instanci třídy Prikaz. Musí být zadáné první a druhé slovo
     * příkazu. Pokud příkaz nemá druhé slovo, zadá se
     * místo něho hodnota null.
     *
     *  Metoda převezme řetězec přečtený z příkazového řádku a vrátí ho jako
     *  instanci třídy Prikaz

     *@param  prvniSlovo   První slovo příkazu
     *@param  druheSlovo  Druhé slovo příkazu
     */
    public Prikaz(String prvniSlovo, String druheSlovo) {
        slovoPrikazu = prvniSlovo;
        this.druheSlovo = druheSlovo;
    }
    /**
     * Druhý konstruktor pro vytvoření instance třídy Prikaz. 
     * Konstruktor převezme řetězec přečtený z příkazového řádku a vytvori
     * instanci třídy Prikaz. Pokud příkaz nemá druhé slovo, zadá se
     * místo něho hodnota null.
     *
     *@param  vstupniRadek   Retezec se vstupnim radkem
     */
    public Prikaz(String vstupniRadek) {

        String [] slova = vstupniRadek.split("[ \t]+");

        if (slova.length > 0) {
            slovoPrikazu = slova[0];          // první slovo
        }
        if (slova.length > 1) {
            druheSlovo = slova[1];          // druhé slovo
        }
        // poznámka: ignoruje se zbytek řádky
    }

    /**
     * Vrací se příkaz (první slovo příkazu). Pokud je to neznámý příkaz,
     * vrací hodnotu null.
     *
     *@return    Příkaz (první slovo příkazu), jako řetězec.
     */
    public String getSlovoPrikazu() {
        return slovoPrikazu;
    }

    /**
     * Vrací druhé slovo příkazu. Pokud neexistuje, vrací se hodnotu null.
     *
     *@return    Druhé slovo příkazu.
     */
    public String getDruheSlovo() {
        return druheSlovo;
    }

    /**
     * Vrací hodnotu true, pokud příkaz má druhé slovo
     *
     *@return    true, pokud má příkaz druhé slovo
     */
    public boolean maDruheSlovo() {
        return (druheSlovo != null);
    }
}

